==> nextcloud-18.0.6.tgz: nextcloud/apps/federatedfilesharing/l10n/th.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "คุณต้องการที่จะเพิ่มรีโมทแชร์ {name} จาก {owner}@{remote}?",
    "Remote share" : "รีโมทแชร์",
    "Remote share password" : "รหัสผ่านรีโมทแชร์",
    "Cancel" : "ยกเลิก",
    "Add remote share" : "เพิ่มรีโมทแชร์",
    "Copy" : "คัดลอก",
    "Copied!" : "คัดลอกแล้ว",
    "Not supported!" : "ไม่สนับสนุน",
    "Press ⌘-C to copy." : "กด ⌘-C เพื่อคัดลอก",
    "Press Ctrl-C to copy." : "กด Ctrl-C เพื่อคัดลอก",
    "Invalid Federated Cloud ID" : "ไอดีคลาวด์ในเครือไม่ถูกต้อง",
    "Server to server sharing is not enabled on this server" : "เซิร์ฟเวอร์ไปยังแชร์เซิร์ฟเวอร์ไม่ได้เปิดใช้งานบนเซิร์ฟเวอร์นี้",
    "Not allowed to create a federated share with the same user" : "ไม่อนุญาตให้สร้างแชร์สหพันธ์กับผู้ใช้เดียวกัน",
    "Federated sharing" : "แบ่งปันสหพันธ์",
    "Accept" : "ยอมรับ",
    "Decline" : "ลดลง",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "แชร์กับฉันผ่าน #Nextcloud ด้วยไอดีคลาวด์สหพันธ์ สามารถดูได้ที่ %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "แชร์กับฉันผ่าน #Nextcloud ด้วยไอดีคลาวด์สหพันธ์",
    "Sharing" : "แชร์ข้อมูล",
    "Federated Cloud Sharing" : "แชร์กับสหพันธ์คลาวด์",
    "Open documentation" : "เปิดเอกสาร",
    "Allow users on this server to send shares to other servers" : "อนุญาตให้ผู้ใช้บนเซิร์ฟเวอร์นี้ส่งแชร์ไปยังเซิร์ฟเวอร์อื่นๆ",
    "Allow users on this server to receive shares from other servers" : "อนุญาตให้ผู้ใช้บนเซิร์ฟเวอร์นี้ได้รับการแชร์จากเซิร์ฟเวอร์อื่นๆ",
    "Federated Cloud" : "สหพันธ์คลาวด์",
    "Your Federated Cloud ID:" : "ไอดีคลาวด์ของคุณ:",
    "Add to your website" : "เพิ่มไปยังเว็บไซต์",
    "Share with me via Nextcloud" : "แชร์กับฉันผ่าน Nextcloud",
    "HTML Code:" : "โค้ด HTML:"
},
"nplurals=1; plural=0;");

==> nextcloud-19.0.7.tgz: nextcloud/apps/federatedfilesharing/l10n/th.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "คุณต้องการที่จะเพิ่มรีโมทแชร์ {name} จาก {owner}@{remote}?",
    "Remote share" : "รีโมทแชร์",
    "Remote share password" : "รหัสผ่านรีโมทแชร์",
    "Cancel" : "ยกเลิก",
    "Add remote share" : "เพิ่มรีโมทแชร์",
    "Copy" : "คัดลอก",
    "Copied!" : "คัดลอกแล้ว",
    "Not supported!" : "ไม่สนับสนุน",
    "Press ⌘-C to copy." : "กด ⌘-C เพื่อคัดลอก",
    "Press Ctrl-C to copy." : "กด Ctrl-C เพื่อคัดลอก",
    "Invalid Federated Cloud ID" : "ไอดีคลาวด์ในเครือไม่ถูกต้อง",
    "Server to server sharing is not enabled on this server" : "เซิร์ฟเวอร์ไปยังแชร์เซิร์ฟเวอร์ไม่ได้เปิดใช้งานบนเซิร์ฟเวอร์นี้",
    "Not allowed to create a federated share with the same user" : "ไม่อนุญาตให้สร้างแชร์สหพันธ์กับผู้ใช้เดียวกัน",
    "Federated sharing" : "แบ่งปันสหพันธ์",
    "Accept" : "ยอมรับ",
    "Decline" : "ลดลง",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "แชร์กับฉันผ่าน #Nextcloud ด้วยไอดีคลาวด์สหพันธ์ สามารถดูได้ที่ %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "แชร์กับฉันผ่าน #Nextcloud ด้วยไอดีคลาวด์สหพันธ์",
    "Sharing" : "แชร์ข้อมูล",
    "Federated Cloud Sharing" : "แชร์กับสหพันธ์คลาวด์",
    "Open documentation" : "เปิดเอกสาร",
    "Allow users on this server to receive shares from other servers" : "อนุญาตให้ผู้ใช้บนเซิร์ฟเวอร์นี้ได้รับการแชร์จากเซิร์ฟเวอร์อื่นๆ",
    "Federated Cloud" : "สหพันธ์คลาวด์",
    "Your Federated Cloud ID:" : "ไอดีคลาวด์ของคุณ:",
    "Add to your website" : "เพิ่มไปยังเว็บไซต์",
    "Share with me via Nextcloud" : "แชร์กับฉันผ่าน Nextcloud",
    "HTML Code:" : "โค้ด HTML:",
    "Allow users on this server to send shares to other servers" : "อนุญาตให้ผู้ใช้บนเซิร์ฟเวอร์นี้ส่งแชร์ไปยังเซิร์ฟเวอร์อื่นๆ"
},
"nplurals=1; plural=0;");
